@@ -57,9 +57,9 @@ public:
     bool eventFilter(QObject *watched, QEvent *event) override;
 
 public Q_SLOTS:
-    void load() Q_DECL_OVERRIDE;
-    void save() Q_DECL_OVERRIDE;
-    void defaults() Q_DECL_OVERRIDE;
+    void load() override;
+    void save() override;
+    void defaults() override;
     void test(const QString &plugin);
 
 Q_SIGNALS:
@@ -106,7 +106,7 @@ public:
         return q->currentWallpaper();
     }
 
-signals:
+Q_SIGNALS:
     void wallpaperConfigurationChanged();
     void currentWallpaperChanged();
 
